@@ -1,8 +1,8 @@
 """Top-level package for sparsemax."""
-
+# fmt: off
 __author__ = """Laksh Aithani"""
-__email__ = 'lakshaithanii@gmail.com'
-__version__ = '0.1.6'
+__email__ = "lakshaithanii@gmail.com"
+__version__ = '0.1.9'
 
 from sparsemax.sparsemax import Sparsemax
-
+# fmt: on
